#[repr(transparent)]pub struct SubstringEntryRow {
inner: TypedObjectRef<SubstringEntryRow, <SubstringEntryRow as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
A AdwPreferencesRow with an embedded text entry, and a fixed text suffix and prefix.
It also has a built-in “Add” button, making it an almost drop-in replacement to EntryAddRow.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<SubstringEntryRow, <SubstringEntryRow as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl SubstringEntryRow
impl SubstringEntryRow
Sourcepub fn input_hints(&self) -> <PhantomData<InputHints> as Property>::Value
pub fn input_hints(&self) -> <PhantomData<InputHints> as Property>::Value
The input hints of the entry.
Sourcepub fn set_input_hints<'a>(
&self,
value: impl Borrow<<<PhantomData<InputHints> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_input_hints<'a>( &self, value: impl Borrow<<<PhantomData<InputHints> as Property>::Value as HasParamSpec>::SetValue>, )
The input hints of the entry.
Sourcepub fn input_purpose(&self) -> <PhantomData<InputPurpose> as Property>::Value
pub fn input_purpose(&self) -> <PhantomData<InputPurpose> as Property>::Value
The input purpose of the entry.
Sourcepub fn set_input_purpose<'a>(
&self,
value: impl Borrow<<<PhantomData<InputPurpose> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_input_purpose<'a>( &self, value: impl Borrow<<<PhantomData<InputPurpose> as Property>::Value as HasParamSpec>::SetValue>, )
The input purpose of the entry.
Sourcepub fn attributes(&self) -> <PhantomData<Option<AttrList>> as Property>::Value
pub fn attributes(&self) -> <PhantomData<Option<AttrList>> as Property>::Value
A list of Pango attributes to apply to the text of the entry.
Sourcepub fn set_attributes<'a>(
&self,
value: Option<impl Borrow<<<PhantomData<Option<AttrList>> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_attributes<'a>( &self, value: Option<impl Borrow<<<PhantomData<Option<AttrList>> as Property>::Value as HasParamSpec>::SetValue>>, )
A list of Pango attributes to apply to the text of the entry.
Sourcepub fn placeholder_text(
&self,
) -> <PhantomData<Option<GString>> as Property>::Value
pub fn placeholder_text( &self, ) -> <PhantomData<Option<GString>> as Property>::Value
The placeholder text of the entry.
Sourcepub fn set_placeholder_text<'a>(
&self,
value: Option<impl Borrow<<<PhantomData<Option<GString>> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_placeholder_text<'a>( &self, value: Option<impl Borrow<<<PhantomData<Option<GString>> as Property>::Value as HasParamSpec>::SetValue>>, )
The placeholder text of the entry.
Sourcepub fn text_length(&self) -> <PhantomData<u32> as Property>::Value
pub fn text_length(&self) -> <PhantomData<u32> as Property>::Value
The length of the text of the entry.
Sourcepub fn prefix_text(&self) -> <PhantomData<GString> as Property>::Value
pub fn prefix_text(&self) -> <PhantomData<GString> as Property>::Value
The prefix text of the entry.
Sourcepub fn set_prefix_text<'a>(
&self,
value: impl Borrow<<<PhantomData<GString> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_prefix_text<'a>( &self, value: impl Borrow<<<PhantomData<GString> as Property>::Value as HasParamSpec>::SetValue>, )
The prefix text of the entry.
Sourcepub fn suffix_text(&self) -> <PhantomData<GString> as Property>::Value
pub fn suffix_text(&self) -> <PhantomData<GString> as Property>::Value
The suffix text of the entry.
Sourcepub fn set_suffix_text<'a>(
&self,
value: impl Borrow<<<PhantomData<GString> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_suffix_text<'a>( &self, value: impl Borrow<<<PhantomData<GString> as Property>::Value as HasParamSpec>::SetValue>, )
The suffix text of the entry.
Sourcepub fn accessible_description(
&self,
) -> <RefCell<Option<String>> as Property>::Value
pub fn accessible_description( &self, ) -> <RefCell<Option<String>> as Property>::Value
Set the accessible description of the entry.
If it is not set, the placeholder text will be used.
Sourcepub fn set_accessible_description<'a>(
&self,
value: Option<impl Borrow<<<RefCell<Option<String>> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_accessible_description<'a>( &self, value: Option<impl Borrow<<<RefCell<Option<String>> as Property>::Value as HasParamSpec>::SetValue>>, )
Set the accessible description of the entry.
If it is not set, the placeholder text will be used.
Whether the add button is hidden.
Whether the add button is hidden.
The tooltip text of the add button.
The tooltip text of the add button.
The accessible label of the add button.
The accessible label of the add button.
Sourcepub fn inhibit_add(&self) -> <Cell<bool> as Property>::Value
pub fn inhibit_add(&self) -> <Cell<bool> as Property>::Value
Whether to prevent the add button from being activated.
Sourcepub fn set_inhibit_add<'a>(
&self,
value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_inhibit_add<'a>( &self, value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether to prevent the add button from being activated.
Sourcepub fn is_loading(&self) -> <PhantomData<bool> as Property>::Value
pub fn is_loading(&self) -> <PhantomData<bool> as Property>::Value
Whether this row is loading.
Sourcepub fn set_is_loading<'a>(
&self,
value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_is_loading<'a>( &self, value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether this row is loading.
Sourcepub fn connect_input_hints_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_input_hints_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the input-hints property
Sourcepub fn connect_input_purpose_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_input_purpose_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the input-purpose property
Sourcepub fn connect_attributes_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_attributes_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the attributes property
Sourcepub fn connect_placeholder_text_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_placeholder_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the placeholder-text property
Sourcepub fn connect_text_length_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_text_length_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the text-length property
Sourcepub fn connect_prefix_text_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_prefix_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the prefix-text property
Sourcepub fn connect_suffix_text_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_suffix_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the suffix-text property
Sourcepub fn connect_accessible_description_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_accessible_description_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the accessible-description property
Listen for notifications of a change in the hide-add-button property
Listen for notifications of a change in the add-button-tooltip-text property
Listen for notifications of a change in the add-button-accessible-label property
Sourcepub fn connect_inhibit_add_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_inhibit_add_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the inhibit-add property
Sourcepub fn connect_is_loading_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_loading_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-loading property
Sourcepub fn notify_input_hints(&self)
pub fn notify_input_hints(&self)
Notify listeners of a change in the input-hints property
Sourcepub fn notify_input_purpose(&self)
pub fn notify_input_purpose(&self)
Notify listeners of a change in the input-purpose property
Sourcepub fn notify_attributes(&self)
pub fn notify_attributes(&self)
Notify listeners of a change in the attributes property
Sourcepub fn notify_placeholder_text(&self)
pub fn notify_placeholder_text(&self)
Notify listeners of a change in the placeholder-text property
Sourcepub fn notify_text_length(&self)
pub fn notify_text_length(&self)
Notify listeners of a change in the text-length property
Sourcepub fn notify_prefix_text(&self)
pub fn notify_prefix_text(&self)
Notify listeners of a change in the prefix-text property
Sourcepub fn notify_suffix_text(&self)
pub fn notify_suffix_text(&self)
Notify listeners of a change in the suffix-text property
Sourcepub fn notify_accessible_description(&self)
pub fn notify_accessible_description(&self)
Notify listeners of a change in the accessible-description property
Notify listeners of a change in the hide-add-button property
Notify listeners of a change in the add-button-tooltip-text property
Notify listeners of a change in the add-button-accessible-label property
Sourcepub fn notify_inhibit_add(&self)
pub fn notify_inhibit_add(&self)
Notify listeners of a change in the inhibit-add property
Sourcepub fn notify_is_loading(&self)
pub fn notify_is_loading(&self)
Notify listeners of a change in the is-loading property
Sourceimpl SubstringEntryRow
impl SubstringEntryRow
pub fn new() -> Self
Sourcepub fn connect_add<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_add<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Connect to the signal emitted when the “Add” button is activated.